@@ -1,3 +1,5 @@
+# (c) cavaliba.com - data - field - date
+
 import datetime
 
 from .field import Field
@@ -7,27 +9,27 @@ from .field import Field
 # -------------
 class FieldDate(Field):
 
-    def merge_edit_data(self, data):
-        self.value = []
-        for i in data:
-            if len(i) > 0:
-                self.value.append(i)
+    # 'YYYY-MM-DD'
 
-    def merge_new_data(self, data):
+    def merge_import(self, data):
+        # no split composite !
         self.value = []
-        for i in data:
-            if len(i) > 0:
-                self.value.append(i)
+        if type(data) is str:
+            if len(data) == 10:
+                self.value = [data]
+        elif type(data) is list:
+            for i in data:
+                if len(i) == 10:
+                    self.value.append(i)
+
                 
     def is_valid(self):
         r = super().is_valid()
         for v in self.value:
             if type(v) is str:
-                if len(v) == 0:
-                    continue            
+                if len(v) != 10:
+                    return False         
             try:
-                # # YYYY-MM-DD
-                # datetime.date.fromisoformat(v)
                 timeformat = "%Y-%m-%d"
                 validtime = datetime.datetime.strptime(v, timeformat)
             except:
