@@ -191,6 +191,11 @@ class Schema:
             return DataClass.objects.filter(keyname=classname).exists()
         return False
 
+    @classmethod
+    def listall_obj(cls):
+        ''' returns a list[] of all DataClass as Db Obj'''
+        return DataClass.objects.all()
+    
 
     @classmethod
     def listall(cls):
