@@ -14,7 +14,7 @@ from django.forms.models import model_to_dict
 
 
 from app_user.aaa import start_command
-from app_user.aaa import get_all_perms
+from app_user.permission import permission_all_keynames
 
 from app_home.home import cavaliba_init
 
@@ -528,7 +528,7 @@ class Command(BaseCommand):
                 if not dryrun:
                     self.stdout.write("Loading to DB...")
                     aaa = {}
-                    aaa["perms"] = get_all_perms()
+                    aaa["perms"] = permission_all_keynames()
 
                     r = load_broker(datalist, aaa=aaa, force_action=force_action, verbose=verbose, progress=progress)
                     #if verbose:
