@@ -27,7 +27,9 @@ from app_user.user import user_get_by_login
 from app_user.user import user_get_by_id
 from app_user.user import user_create
 
-from app_user.role import role_get_by_name
+#from app_user.role import role_get_by_name
+from app_user.role import role_get_permissions
+from app_user.permission import permission_all_keynames
 
 
 # ==============================================================================
@@ -520,8 +522,7 @@ def get_aaa(request, auth_mode = None, impersonate=None, impersonate_by=None):
     aaa["groups"] = list(set(aaa["groups_direct"] + aaa["groups_computed"] + aaa["groups_indirect"]))
 
     # add perms & roles to aaa 
-    tmp = get_permissions_for_aaa(aaa)
-    aaa["perms"] = [i.keyname for i in tmp] 
+    aaa["perms"] = role_get_permissions(aaa["groups"])
 
     if debug_aaa == "yes":
         print("DEBUG_AAA - groups direct/computed/indirect and perms computed: ", len(aaa["groups"]))
@@ -545,7 +546,7 @@ def get_aaa(request, auth_mode = None, impersonate=None, impersonate_by=None):
 
     if aaa["is_admin"]:
         # give all groups, all perms
-        aaa["perms"] = get_all_perms()
+        aaa["perms"] = permission_all_keynames()
         aaa["groups"] = get_all_groups()
         if debug_aaa == "yes":
             print("DEBUG_AAA - all groups, perms for admin")
@@ -567,16 +568,7 @@ def get_current_user(aaa):
     except:
         return
     
-# ------------------------------------
-# get all perms
-# ------------------------------------
-def get_all_perms():
 
-    perms = []
-    dbperms = SirenePermission.objects.all()
-    for p in dbperms:
-        perms.append(p.keyname)
-    return perms
 
 # ------------------------------------
 # get all groups
@@ -661,19 +653,7 @@ def get_groups_for_user(user, mode="name"):
         return direct, computed, indirect
 
 
-# ---------------------------------------
-# permission
-# ---------------------------------------
 
-def get_permissions_for_aaa(aaa):
-    perms = []
-    for g in aaa["groups"]:
-        gobj = role_get_by_name(g, enabled_only=True)
-        if gobj:
-            for perm in gobj.permissions.all():
-                perms.append(perm)
-    perms = list(set(perms))
-    return perms
 
 
 
