@@ -377,9 +377,13 @@ def user_listdict_format(users):
         # remove null values
         m2= {}
         for k,v in m.items():
-            if v:
+            if not isinstance(v,bool):
+                if v:
+                    m2[k] = v
+            else:
                 m2[k] = v
 
+
         mylist.append(m2)
 
     return mylist
